CloudSyncStatus enum

Status of the cloud sync service. Kept for backwards compatibility.

Inheritance
Available extensions

Values

disabled → const CloudSyncStatus

Sync is disabled or not configured.

idle → const CloudSyncStatus

Service is idle, ready to sync.

syncing → const CloudSyncStatus

Currently syncing logs.

error → const CloudSyncStatus

Recent sync failed.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CloudSyncStatus>
A constant List of the values in this enum, in order of their declaration.