apiKey property
API key for authentication.
This is the primary identifier. The server derives the project from this key, so explicit projectId is not required.
Implementation
final String? apiKey;
API key for authentication.
This is the primary identifier. The server derives the project from this key, so explicit projectId is not required.
final String? apiKey;