projectId property
Project ID (optional, for local reference only).
The server derives the actual project from the API key.
Implementation
final String? projectId;
Project ID (optional, for local reference only).
The server derives the actual project from the API key.
final String? projectId;