LogEntry class

Implementers
Available extensions

Constructors

LogEntry({required String id, required DateTime timestamp, required String message, required LogLevel level, String? category, String? tag, Map<String, dynamic>? metadata, Object? error, String? stackTrace, String? userId, String? sessionId, String? context, String? appVersion, String? deviceId})
const

Properties

appVersion → String?
final
category → String?
final
context → String?
final
deviceId → String?
final
error → Object?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
level → LogLevel
final
message → String
final
metadata → Map<String, dynamic>?
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId → String?
final
stackTrace → String?
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
tag → String?
final
timestamp → DateTime
final
userId → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toModel() → LogEntryModel

Available on LogEntry, provided by the LogEntryExtensions extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited