The list of properties that will be used to determine whether
two instances are equal.
Implementation
@override
List<Object?> get props => [id, timestamp, message, level, category, tag, metadata, error, stackTrace, userId, sessionId, context, appVersion, deviceId];