LogStatistics class

Statistics about stored logs Same as before, but now powered by Sembast

Available extensions

Constructors

LogStatistics({required int totalLogs, required Map<String, int> levelCounts, required Map<String, int> categoryCounts, Map<String, int>? tagCounts, DateTime? earliestLog, DateTime? latestLog})
LogStatistics.empty()
Factory method to create empty statistics
factory

Properties

categoryCounts → Map<String, int>
final
earliestLog → DateTime?
final
hashCode → int
The hash code for this object.
no setterinherited
latestLog → DateTime?
final
levelCounts → Map<String, int>
final
logsPerDay → double?
Logs per day average
no setter
newestLog → DateTime?
no setter
oldestLog → DateTime?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tagCounts → Map<String, int>
final
timeSpan → Duration?
Duration covered by logs
no setter
totalLogs → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited