PrettyLogFormatter class

Constructors

PrettyLogFormatter({bool enabled = true, bool showEmojis = true, bool showTimestamp = true, bool showColors = true, bool showBorders = true, bool showMetadata = true, int lineLength = 120})
const

Properties

enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
lineLength → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showBorders → bool
final
showColors → bool
final
showEmojis → bool
final
showMetadata → bool
final
showTimestamp → bool
final

Methods

format(LogEntry entry) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited