features/logging/logging library

Logging feature barrel file Main logging functionality exports

Classes

CloudSyncConfig
Configuration for cloud sync of logs to a backend API.
LogEntry
LogEntryModel
LogFilter
Filter criteria for querying logs
LoggerContext
Contextual logger for specific modules Why? Automatically adds category/tag context so you don't have to repeat it
LoggerRepository
LoggerRepositoryImpl
LoggingConfig
Configuration for VooLogger output and behavior.
LogStatistics
Statistics about stored logs Same as before, but now powered by Sembast
LogTypeConfig
VooLogger
A zero-config logger for Flutter applications.

Enums

LogType

Typedefs

ErrorCaptureCallback = void Function({String? errorType, required String message, String? stackTrace})
Callback for external error capture (e.g., replay capture).